
.. _wml:

Wireless Markup Language
************************
This page documents the support for `WML
<https://en.wikipedia.org/wiki/Wireless_Markup_Language>`_ and is used for
planning our work on it.

This is implemented as a generic XML document type that is handled similarly to
the way the :doc:`developers/projects/odf` project handles ODF documents.
